@@ -27,7 +27,7 @@ export FULLPKG=${PKG}-${VER}-${REL}
 # if the orig src package is bzip2'ed, remember to
 # change 'z' to 'j' in the 'tar xvzf' commands in the
 # prep) and mkpatch) sections
-export src_orig_pkg_name=docbk31.zip
+export src_orig_pkg_name=docbk40.zip
 export src_pkg_name=${FULLPKG}-src.tar.bz2
 export src_patch_name=${FULLPKG}.patch
 export bin_pkg_name=${FULLPKG}.tar.bz2
@@ -61,7 +61,6 @@ prep() {
   mkdir ${PKG}-${VER} && \
   cd ${PKG}-${VER} && \
   unzip ${src_orig_pkg} ; \
-    d2u *; \
   cd ${topdir} && \
   patch -p0 < ${src_patch} 
   && mkdirs )
@@ -145,7 +144,6 @@ mkpatch() {
   mkdir ${PKG}-${VER} && \
   cd ${PKG}-${VER} && \
   unzip ${src_orig_pkg} && \
-    d2u * && \
   cd .. ;\
   mv ${PKG}-${VER} ../${PKG}-${VER}-orig && \
   cd ${topdir} && \
